<?php

namespace Drupal\Tests\toolbar_language_switcher\Functional;

use Drupal\Core\Url;
use Drupal\language\Entity\ConfigurableLanguage;
use Drupal\Tests\BrowserTestBase;
use Drupal\Tests\user\Traits\UserCreationTrait;

/**
 * Base test class for toolbar_language_switcher tests.
 *
 * @group toolbar_language_switcher
 */
class ToolbarLanguageSwitcherTest extends BrowserTestBase {

  use UserCreationTrait;

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * Modules to install.
   *
   * @var array
   */
  public static $modules = [
    'toolbar_language_switcher',
  ];

  /**
   * A test user.
   *
   * @var \Drupal\user\UserInterface
   */
  protected $user;

  /**
   * A user role id.
   *
   * @var string
   */
  protected $rid;

  /**
   * Custom languages.
   *
   * @var array
   */
  protected $languages = [
    'xx' => 'Lolspeak',
    'zz' => 'Lolspeak2',
  ];

  /**
   * A permitted user.
   *
   * @var \Drupal\user\UserInterface
   */
  protected $permitted_user;

  /**
   * {@inheritdoc}
   */
  protected function setUp() {
    parent::setUp();
    $this->installLanguages();
    $this->user = $this->drupalCreateUser(['access toolbar']);
    $this->permitted_user = $this->drupalCreateUser([
      'access toolbar',
      'use toolbar_language_switcher',
    ]);
  }

  /**
   * Test use use toolbar_language_switcher permission.
   */
  public function testNotRenderedForTheForbiddenUser() {
    $front_page = Url::fromRoute('<front>');
    $assert_session = $this->assertSession();
    $this->drupalLogin($this->user);
    $this->drupalGet($front_page);
    foreach ($this->languages as $title) {
      $assert_session->linkNotExists($title);
    }
    $this->drupalLogin($this->permitted_user);
    $this->drupalGet($front_page);
    foreach ($this->languages as $title) {
      $assert_session->linkExists($title);
    }
  }

  /**
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  public function installLanguages() {
    foreach ($this->languages as $langcode) {
      $language = ConfigurableLanguage::createFromLangcode($langcode);
      $language->save();
    }
  }

}
